@@ -282,9 +282,7 @@ class Config:
     def __init__(self):
         # First, load the .env file, which adds environment variables to the
         # the program.
-        logger.info("Reading environment variables. Looking for a .env file.")
         load_dotenv(verbose=True)
-        print(os.environ)
 
         self.default_settings = None
         self.custom_settings = {}
